Welcome to Inspect Scout.

## Installation

Latest development version:

```bash
pip install git+https://github.com/meridianlabs-ai/inspect_scout
```

## Development

To work on development of Inspect Scout, clone the repository and install with the `-e` flag and `[dev]` optional dependencies:

```bash
git clone https://github.com/meridianlabs-ai/inspect_scout
cd inspect_scout
pip install -e ".[dev]"
```

Run linting, formatting, and tests via

```bash
make check
make test
```


